@@ -1,6 +1,7 @@
 import spacy
 from spacy.tokenizer import Tokenizer
 from spacy.language import Language
+from tokenizers import ByteLevelBPETokenizer
 import re
 
 def spacy_extended(nlp):
@@ -101,10 +102,6 @@ class SpacyHFTok(object):
     import spacy
     import numpy as np
 
-    # Check scispacy models
-    from medcat.utils.helpers import check_scispacy
-    check_scispacy()
-
     def __init__(self, w2v):
         self.nlp = spacy.load('en_core_sci_md', disable=['ner', 'parser'])
         self.emb_map = {}
@@ -129,3 +126,33 @@ class SpacyHFDoc(object):
         self.doc = doc
         self.tokens = [x.text for x in self.doc]
         self.offsets = [(x.idx, x.idx+len(x.text)) for x in self.doc]
+
+
+class TokenizerWrapperBPE(object):
+    '''
+    '''
+
+    def __init__(self, hf_tokenizers=None):
+        self.hf_tokenizers = hf_tokenizers
+
+
+    def __call__(self, text):
+        res = self.hf_tokenizers.encode(text)
+
+        return {'offset_mapping': res.offsets,
+                'input_ids': res.ids,
+                'tokens': res.tokens,
+                }
+
+
+    def save(self, dir_path, name='bbpe'):
+        self.hf_tokenizers.save_model(dir_path, name=name)
+
+    @classmethod
+    def load(cls, dir_path, name='bbpe', lowercase=True):
+        tokenizer = cls()
+        vocab_file = dir_path + "{}-vocab.json".format(name)
+        merges_file = dir_path + "{}-merges.txt".format(name)
+        tokenizer.hf_tokenizer = ByteLevelBPETokenizer.from_file(vocab_filename=vocab_file, merges_filename=merges_file, lowercase=lowercase)
+
+        return tokenizer
